@@ -107,6 +107,14 @@ summary.GWAS <- function(object,
           "of them were not analyzed because their minor allele frequency is",
           "below", GWASInfo$MAF, "\n\n")
     }
+    ## Print GLSMethod.
+    cat("\tGLSMethod:", GWASInfo$GLSMethod, "\n")
+    if (!is.null(GWASInfo$kinshipMethod)) {
+      ## Print kinshipmethod.
+      cat("\tkinshipMethod:", GWASInfo$kinshipMethod, "\n\n")
+    } else {
+      cat("\n")
+    }
     for (trait in traitsTr) {
       cat("\tTrait:", trait, "\n\n")
       if (substr(GWASInfo$call[[1]], 4, 4) == "S" &&
@@ -197,13 +205,21 @@ summary.GWAS <- function(object,
 #' \item{\code{signLwd}}{A numerical value giving the thickness of the
 #' points that are false/true positives/negatives. Default = 0.6}
 #' \item{\code{lod}}{A positive numerical value. For the SNPs with a LOD-value
-#' below this value, only 5\% is plotted. The chance of a SNP being plotted is
+#' below this value, only 5% is plotted. The chance of a SNP being plotted is
 #' proportional to its LOD-score. This option can be useful when plotting a
-#' large number of SNPs. The 5\% of SNPs plotted is selected randomly. For 
+#' large number of SNPs. The 5% of SNPs plotted is selected randomly. For 
 #' reproducible results use set.seed before calling the function.}
 #' \item{\code{chr}}{A vector of chromosomes to be plotted. By default, all
 #' chromosomes are plotted. Using this option allows restricting the plot to a
 #' subset of chromosomes.}
+#' \item{\code{startPos}}{A numerical value indicating the start position for
+#' the plot. Using this option allows restricting the plot to a part of a 
+#' selected chromosome. Only used if exactly one chromosome is specified in 
+#' \code{chr}.}
+#' \item{\code{endPos}}{A numerical value indicating the end position for
+#' the plot. Using this option allows restricting the plot to a part of a 
+#' selected chromosome. Only used if exactly one chromosome is specified in 
+#' \code{chr}.}
 #' }
 #'
 #' @section QQ-Plot:
@@ -256,9 +272,83 @@ summary.GWAS <- function(object,
 #' @param trait A character string indicating for which trait the results
 #' should be plotted. For \code{type} "qtl" all traits are plotted. If \code{x}
 #' only contains results for one trait, \code{trait} may be \code{NULL}.
+#' @param title A character string, the title of the plot.
 #' @param output Should the plot be output to the current device? If
 #' \code{FALSE}, only a list of ggplot objects is invisibly returned.
 #'
+#' @examples 
+#' ## Create a gData object Using the data from the DROPS project.
+#' ## See the included vignette for a more extensive description on the steps.
+#' data(dropsMarkers)
+#' data(dropsMap)
+#' data(dropsPheno)
+#' 
+#' ## Add genotypes as row names of dropsMarkers and drop Ind column.
+#' rownames(dropsMarkers) <- dropsMarkers[["Ind"]]
+#' dropsMarkers <- dropsMarkers[colnames(dropsMarkers) != "Ind"]
+#' 
+#' ## Add genotypes as row names of dropsMap.
+#' rownames(dropsMap) <- dropsMap[["SNP.names"]]
+#' 
+#' ## Rename Chomosome and Position columns.
+#' colnames(dropsMap)[match(c("Chromosome", "Position"), 
+#'                    colnames(dropsMap))] <- c("chr", "pos")
+#'                    
+#' ## Convert phenotypic data to a list.
+#' dropsPhenoList <- split(x = dropsPheno, f = dropsPheno[["Experiment"]])
+#' 
+#' ## Rename Variety_ID to genotype and select relevant columns.
+#' dropsPhenoList <- lapply(X = dropsPhenoList, FUN = function(trial) {
+#'   colnames(trial)[colnames(trial) == "Variety_ID"] <- "genotype"
+#'   trial <- trial[c("genotype", "grain.yield", "grain.number", "seed.size",
+#'                  "anthesis", "silking", "plant.height", "tassel.height",
+#'                  "ear.height")]
+#' return(trial)
+#' }) 
+#' 
+#' ## Create gData object.
+#' gDataDrops <- createGData(geno = dropsMarkers, map = dropsMap, 
+#'                           pheno = dropsPhenoList)
+#'                           
+#' ## Run single trait GWAS for trait 'grain.yield' for trial Mur13W.
+#' \donttest{
+#' GWASDrops <- runSingleTraitGwas(gData = gDataDrops,
+#'                                trials = "Mur13W",
+#'                                traits = "grain.yield")
+#'                                
+#' ## Create a manhattan plot.
+#' plot(GWASDrops)
+#' 
+#' ## Manually set a threshold for significant snps and add a title.
+#' plot(GWASDrops, 
+#'     yThr = 3.5, 
+#'     title = "Manhattan plot for Mur13W")
+#'     
+#' ## Restrict plot to part of chr 6.
+#' plot(GWASDrops, 
+#'     yThr = 3.5, 
+#'     chr = 6,
+#'     startPos = 0,
+#'     endPos = 110000000)
+#'     
+#' ## Create a qq plot.
+#' plot(GWASDrops, 
+#'     plotType = "qq",
+#'     title = "QQ plot for Mur13W")
+#'     
+#' ## Create a QTL plot.
+#' plot(GWASDrops,
+#'     plotType = "qtl",
+#'     title = "QTL plot for Mur13W")
+#'     
+#' ## Manually set a threshold and don't show vertical lines.
+#' plot(GWASDrops,     
+#'     plotType = "qtl",
+#'     yThr = 3.5,
+#'     printVertGrid = FALSE,
+#'     title = "QTL plot for Mur13W")          
+#' }
+#'
 #' @references Millet et al. (2016) Genome-wide analysis of yield in Europe:
 #' Allelic effects vary with drought and heat scenarios. Plant Physiology,
 #' October 2016, Vol. 172, p. 749–764
@@ -272,9 +362,11 @@ plot.GWAS <- function(x,
                       plotType = c("manhattan", "qq", "qtl"),
                       trial = NULL,
                       trait = NULL,
+                      title = NULL,
                       output = TRUE) {
   plotType <- match.arg(plotType)
   dotArgs <- list(...)
+  type <- match.arg(dotArgs$type, c("dots", "lines"))
   ## Checks.
   if (!is.null(trial) && !is.character(trial) &&
       !is.numeric(trial)) {
@@ -324,6 +416,30 @@ plot.GWAS <- function(x,
       if (nrow(GWAResult) == 0) {
         stop("Select at least one valid chromosome for plotting.\n")
       }
+      if (length(dotArgs$chr) == 1) {
+        ## when plotting 1 chromosome, restrict plot range according to 
+        ## startPos and endPos.
+        startPos <- dotArgs$startPos
+        endPos <- dotArgs$endPos
+        if (!is.null(startPos)) {
+          chkNum(startPos, min = 0, max = max(GWAResult[["pos"]]))
+        } else {
+          startPos <- 0 
+        }
+        if (!is.null(endPos)) {
+          chkNum(endPos, min = 0)
+        } else {
+          endPos <- max(GWAResult[["pos"]])
+        }
+        if (startPos > endPos) {
+          stop("Start position should be smaller than end position.\n")
+        }
+        GWAResult <- GWAResult[GWAResult[["pos"]] >= startPos &
+                                 GWAResult[["pos"]] <= endPos, ]
+        if (nrow(GWAResult) == 0) {
+          stop("No SNPs in selected range.\n")
+        }
+      }
     }
     ## Get the boundary for each of the chromosomes. 
     ## Has to be converted to numeric to avoid integer overflow in the next step.
@@ -378,15 +494,16 @@ plot.GWAS <- function(x,
     ## Create manhattan plot.
     do.call(manhattanPlot,
             args = c(list(xValues = map$cumPos, yValues = map$LOD,
-                          map = map, xSig = signSnpNr, xEffects = xEffects,
-                          chrBoundaries = chrBnd[, 2], yThr = yThr,
-                          output = output),
+                          plotType = type, map = map, xSig = signSnpNr, 
+                          xEffects = xEffects, chrBoundaries = chrBnd[, 2], 
+                          yThr = yThr, title = title, output = output),
                      dotArgs[!(names(dotArgs) %in% c("yThr", "lod", "chr",
                                                      "effects"))]
             ))
   } else if (plotType == "qq") {
     ## Create QQ-plot.
-    qqPlot(pValues = na.omit(GWAResult$pValue), ..., output = output)
+    qqPlot(pValues = na.omit(GWAResult$pValue), title = title, ..., 
+           output = output)
   } else if (plotType == "qtl") {
     if (!is.null(dotArgs$yThr)) {
       ## Threshold modified, update significant SNPs.
@@ -416,7 +533,8 @@ plot.GWAS <- function(x,
       }
     }
     do.call(qtlPlot,
-            args = c(list(dat = GWAResult, map = map, output = output),
+            args = c(list(dat = GWAResult, map = map, title = title, 
+                          output = output),
                      dotArgs[!(names(dotArgs) %in% c("yThr", "chr"))]
             ))
   } 
