@@ -17,22 +17,22 @@ expect_error(summary(stg0, trials = 7),
 sumStg0 <- capture.output(summary(stg0))
 expect_true(any(grepl(pattern = "Traits analysed: X1, X2, X3, X4, X5", 
                       x = sumStg0)))
-expect_true(any(grepl(pattern = "Data are available for 3 SNPs", x = sumStg0)))
+expect_true(any(grepl(pattern = "Data are available for 4 SNPs", x = sumStg0)))
 expect_true(any(grepl(pattern = "0 of them were not analyzed", x = sumStg0)))
-expect_true(any(grepl(pattern = "Genetic variance: 0.02108507", x = sumStg0)))
-expect_true(any(grepl(pattern = "Residual variance: 1.853736", x = sumStg0)))
-expect_true(any(grepl(pattern = "LOD-threshold: 1.778151", x = sumStg0)))
+expect_true(any(grepl(pattern = "Genetic variance: 9.80734e-05", x = sumStg0)))
+expect_true(any(grepl(pattern = "Residual variance: 2.16021", x = sumStg0)))
+expect_true(any(grepl(pattern = "LOD-threshold: 1.90309", x = sumStg0)))
 expect_true(any(grepl(pattern = "No significant SNPs found", x = sumStg0)))
 expect_true(any(grepl(pattern = "No genomic control correction", x = sumStg0)))
-expect_true(any(grepl(pattern = "inflation-factor: 0.224", x = sumStg0)))
+expect_true(any(grepl(pattern = "inflation-factor: 1.179", x = sumStg0)))
 
 sumStg1 <- capture.output(summary(stg1))
 expect_true(any(grepl(pattern = "Number of significant SNPs: 1", x = sumStg1)))
-expect_true(any(grepl(pattern = "Smallest p-value among the significant SNPs: 0.5565652",
+expect_true(any(grepl(pattern = "Smallest p-value among the significant SNPs: 0.2249729",
                       x = sumStg1)))
-expect_true(any(grepl(pattern = "Largest p-value among the significant SNPs: 0.5565652",
+expect_true(any(grepl(pattern = "Largest p-value among the significant SNPs: 0.2249729",
                       x = sumStg1)))
-expect_true(any(grepl(pattern = "LOD-score: 0.2544839", x = sumStg1)))
+expect_true(any(grepl(pattern = "LOD-score: 0.6478698", x = sumStg1)))
 
 sumStgM0 <- capture.output(summary(stgM0))
 expect_false(any(grepl(pattern = "Genetic variance", x = sumStgM0)))
